@@ -17,7 +17,9 @@ pub struct Timer<'callback> {
 
 impl std::fmt::Debug for Timer<'_> {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        f.debug_struct("Timer").field("id", &self.id).finish()
+        f.debug_struct("Timer")
+            .field("id", &self.id)
+            .finish_non_exhaustive()
     }
 }
 
