@@ -15,7 +15,7 @@ pub struct Palette {
 
 impl std::fmt::Debug for Palette {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        f.debug_struct("Palette").finish()
+        f.debug_struct("Palette").finish_non_exhaustive()
     }
 }
 
