@@ -55,9 +55,8 @@ pub struct Texture<'renderer> {
 impl std::fmt::Debug for Texture<'_> {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         f.debug_struct("Texture")
-            .field("texture", &self.texture)
             .field("clip", &self.clip)
-            .finish()
+            .finish_non_exhaustive()
     }
 }
 
